@@ -23,24 +23,15 @@
 #include <gnome.h>
 #include "config_common.h"
 
-typedef struct
-{
-  GtkWidget *cat_window;
-  GtkWidget *cat_clist;
-  gint selected_row;
-  gpointer tmpdata;
-  guint cat_id, tmpcount;
-}
-CATEGORY_WIDGETS;
 
 void _set_category_name(gchar *string, gpointer data);
-void add_the_categorie(GtkWidget *w, gpointer data);
-void edit_the_categorie(GtkWidget *w, gpointer data);
-void del_the_categorie(GtkWidget *w, gpointer data);
+void add_the_categorie(GtkWidget *w, FOLDER *racine);
+void edit_the_categorie(GtkWidget *w, FOLDER *racine);
+void del_the_categorie(GtkWidget *w, FOLDER *racine);
 void cat_selected(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
 void cat_unselected(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
-gboolean category_count(GNode *gn, gpointer data);
-GList *make_categories_list(CONFIG *my_config);
-void edit_categories(GtkWidget *w, gpointer data);
+gboolean category_count (GNode * gn, gpointer data);
+GList *make_categories_list(FOLDER * racine);
+void edit_categories (FOLDER *racine);
 
 #endif
