@@ -355,8 +355,7 @@ get_description (FOLDER * racine, guint16 i)
     }
 }
 
-gboolean
-is_file (GNode * gn)
+gboolean is_file (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -366,8 +365,7 @@ is_file (GNode * gn)
   return (FALSE);
 }
 
-gboolean
-is_dir (GNode * gn)
+gboolean is_dir (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -377,8 +375,7 @@ is_dir (GNode * gn)
   return (FALSE);
 }
 
-gboolean
-is_link (GNode * gn)
+gboolean is_link (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -390,8 +387,7 @@ is_link (GNode * gn)
 
 
 
-gboolean
-is_disk (GNode * gn)
+gboolean is_disk (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -432,47 +428,34 @@ folder_search_name_in_array (GNode * gn, gchar * name)
 }
 
 
-gboolean
-_gnode_clear_data (GNode * gn, gpointer data)
+gboolean _gnode_clear_data (GNode * gn, gpointer data)
 {
   FOLDER *f = data;
   FILE_DATA *fd;
 
-  fd = get_file_data_from_gnode (gn);
-  if (fd->name)
-    g_string_free (fd->name, TRUE);
-  if (fd->information)
-    g_string_free (fd->information, TRUE);
+  if (G_NODE_IS_ROOT (gn) != TRUE)
+    {
+      fd = get_file_data_from_gnode (gn);
+      if (fd->name)
+	g_string_free (fd->name, TRUE);
+      if (fd->information)
+	g_string_free (fd->information, TRUE);
 
-  g_free (fd);
+      g_free (fd);
 /* warning: the FILE_DATA entry in the GPtrArray is just set to NULL. It is not suppressed here. */
-  g_ptr_array_index (f->datas, GPOINTER_TO_UINT (gn->data)) = NULL;
-  if (!G_NODE_IS_ROOT (gn))
-    gn->data = NULL;
+      g_ptr_array_index (f->datas, GPOINTER_TO_UINT (gn->data)) = NULL;
+    }
   return (FALSE);
 }
 
-/* empty the main FOLDER structure */
-void
-folder_free (FOLDER * racine)
-{
-  g_node_traverse (racine->tree, G_IN_ORDER, G_TRAVERSE_ALL, -1,
-		   _gnode_clear_data, racine);
-  racine->tree->data = NULL;
-  g_node_destroy (racine->tree);
-
-  g_ptr_array_free (racine->datas, FALSE);
-
-  racine->tree = NULL;
-  racine->datas = NULL;
-}
-
-gboolean _gnode_clear_ctree_data (GNode * gn, gpointer data)
+gboolean
+_gnode_clear_ctree_data (GNode * gn, gpointer data)
 {
   FOLDER *racine = data;
   FILE_DATA *fd;
 
-  if ((is_dir (gn) == TRUE) || (is_disk (gn) == TRUE))
+  if (((is_dir (gn) == TRUE) || (is_disk (gn) == TRUE))
+      && (G_NODE_IS_ROOT (gn) != TRUE))
     {
       fd = get_file_data_from_gnode (gn);
       if (fd->ctree_node)
@@ -494,17 +477,29 @@ suppress_dir (GNode * dir)
   gint i;
 
   racine = get_catalog_from_gnode (dir);
-
   gpa = racine->datas;
   fd = get_file_data_from_gnode (dir);
-  if ((is_dir (dir) == TRUE) || (is_disk (dir) == TRUE))
+  if ((is_dir (dir) == TRUE) || (is_disk (dir) == TRUE)
+      || (G_NODE_IS_ROOT (dir) == TRUE))
     {
       g_node_traverse (dir, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 		       _gnode_clear_ctree_data, racine);
-      gtk_ctree_remove_node (GTK_CTREE (racine->ctree), fd->ctree_node);
+      if (G_NODE_IS_ROOT (dir) != TRUE)
+	gtk_ctree_remove_node (GTK_CTREE (racine->ctree), fd->ctree_node);
     }
   g_node_traverse (dir, G_PRE_ORDER, G_TRAVERSE_ALL, -1, _gnode_clear_data,
 		   racine);
+
+  if ((G_NODE_IS_ROOT (dir) == TRUE))
+    {
+      fd = get_file_data_from_gnode (dir);
+      if (fd->name)
+	g_string_free (fd->name, TRUE);
+      if (fd->information)
+	g_string_free (fd->information, TRUE);
+
+      g_free (fd);
+    }
   g_node_unlink (dir);
   g_node_destroy (dir);
 
