@@ -23,19 +23,18 @@
 #include <gnome.h>
 #include "config_common.h"
 
+void ctree_window_add(GtkWidget *ctree);
 void traverse_add_dir_to_clist(GNode *gn, gpointer data);
+void catalog_set_selected_folder(GNode *gn);
 void traverse_add_file_to_clist(GNode *gn, gpointer data);
-void list_folder(GNode *parent, CONFIG *my_config);
-void quit_prog(GtkWidget *w, CONFIG *my_config);
-gboolean add_disk_to_ctree(GNode *gn, gpointer data);
-gint find_viewer(gpointer key, gpointer value, gpointer data);
+void list_folder(GNode *parent);
+EXTENSIONS *find_extension (gchar * file);
 void fin_fils(int sig);
 void clist_pressed(GtkWidget *wid, GdkEventButton *event, gpointer data);
-GtkWidget *create_list(CONFIG *my_config);
+GtkWidget *create_list();
 void tree_pressed(GtkWidget *wid, GdkEventButton *event, gpointer data);
-GtkWidget *create_tree(CONFIG *my_config);
-void update_tree(CONFIG *my_config);
-void clean_description(GtkWidget *w, gpointer data);
-
+void update_tree(FOLDER *racine);
+void clean_description (FOLDER *racine);
+void build_gui();
 
 #endif
