@@ -25,14 +25,17 @@
 #include "config_common.h"
 
 
-void open_cat_ok_sel(GtkWidget *w, CONFIG *my_config);
-void open_cat(GtkWidget *w, gpointer data);
-void init_file(CONFIG *my_config);
-void new_file(GtkWidget *w, CONFIG *my_config);
-void clear_all(GtkWidget *w, CONFIG *my_config);
-void save_cat_ok_sel(GtkWidget *w, CONFIG *my_config);
-void save_cat(GtkWidget *w, CONFIG *my_config);
-void fast_save(GtkWidget *w, CONFIG *my_config);
+gboolean add_gnode_to_ctree (GNode * gn, gpointer data);
+void open_cat_ok_sel(GtkWidget *w, gpointer data);
+void open_cat (FOLDER *racine);
+void create_tree(FOLDER *racine);
+FOLDER *init_folder(void);
+void new_file();
+void clear_folder(FOLDER *racine);
+void save_cat_ok_sel(GtkWidget *w, FOLDER *racine);
+void save_cat(FOLDER *racine);
+void fast_save(FOLDER *racine);
 const gint string_to_index(GPtrArray *a, gchar *s);
 
 #endif
+/* io.c */
