@@ -35,6 +35,7 @@ read_gstring (int fh)
   gchar *s;
 
   read (fh, &l, sizeof (gint));
+  l = GINT_FROM_LE (l);
   if (l)
     {
       s = (gchar *) g_malloc (sizeof (gchar) * (l + 1));
@@ -59,6 +60,7 @@ gzread_gstring (gzFile gzfh)
   gchar *s;
 
   gzread (gzfh, &l, sizeof (gint));
+  l = GINT_FROM_LE (l);
   if (l)
     {
       s = (gchar *) g_malloc (sizeof (gchar) * (l + 1));
@@ -79,26 +81,40 @@ FILE_DATA *
 read_filedata (gzFile gzfh, int fh)
 {
   FILE_DATA *d;
+  guint32 le32;
+  guint16 le16;
+  guint le;
+
   d = (FILE_DATA *) g_malloc (sizeof (FILE_DATA));
   if (fh >= 0)
     {
       d->name = read_gstring (fh);
-      read (fh, &(d->taille), sizeof (guint32));
-      read (fh, &(d->type), sizeof (guint));
-      read (fh, &(d->date), sizeof (time_t));
-      read (fh, &(d->categorie), sizeof (guint16));
-      read (fh, &(d->description), sizeof (guint16));
+      read (fh, &le32, sizeof (guint32));
+      d->taille = GUINT32_FROM_LE (le32);
+      read (fh, &le, sizeof (guint));
+      d->type = GUINT_FROM_LE (le);
+      read (fh, &le32, sizeof (guint32));
+      d->date = GUINT32_FROM_LE (le32);
+      read (fh, &le16, sizeof (guint16));
+      d->categorie = GUINT16_FROM_LE (le16);
+      read (fh, &le16, sizeof (guint16));
+      d->description = GUINT16_FROM_LE (le16);
       d->information = read_gstring (fh);
 
     }
   else
     {
       d->name = gzread_gstring (gzfh);
-      gzread (gzfh, &(d->taille), sizeof (guint32));
-      gzread (gzfh, &(d->type), sizeof (guint));
-      gzread (gzfh, &(d->date), sizeof (time_t));
-      gzread (gzfh, &(d->categorie), sizeof (guint16));
-      gzread (gzfh, &(d->description), sizeof (guint16));
+      gzread (gzfh, &le32, sizeof (guint32));
+      d->taille = GUINT32_FROM_LE (le32);
+      gzread (gzfh, &le, sizeof (guint));
+      d->type = GUINT_FROM_LE (le);
+      gzread (gzfh, &le32, sizeof (guint32));
+      d->date = GUINT32_FROM_LE (le32);
+      gzread (gzfh, &le16, sizeof (guint16));
+      d->categorie = GUINT16_FROM_LE (le16);
+      gzread (gzfh, &le16, sizeof (guint16));
+      d->description = GUINT16_FROM_LE (le16);
       d->information = gzread_gstring (gzfh);
     }
   return (d);
@@ -167,6 +183,8 @@ load_gptrarray_of_gstrings (gzFile gzfh, int fh)
     read (fh, &nb_datas, sizeof (gint));
   else
     gzread (gzfh, &nb_datas, sizeof (gint));
+  nb_datas = GINT_FROM_LE (nb_datas);
+  i = GINT_FROM_LE (i);
   for (i = 0; i < nb_datas; i++)
     {
       if (fh >= 0)
@@ -181,39 +199,63 @@ int
 load_cat_from_file (char *filename, FOLDER * racine)
 {
   char fileformat[MAX_STRING_LENGTH];
-  gint l;
+  gint l, le;
   int catalog;
   gzFile gzcatalog;
 
+/* Test if the file exists */
   if ((g_file_test (filename, G_FILE_TEST_ISFILE)) != TRUE)
     {
       ERROR_DIALOG ("File does not exist or is not a standard file",
 		    main_window);
       return (-1);
     }
+
+/* Opens the file */
   if ((catalog = open (filename, O_RDONLY)) == -1)
     {
       ERROR_DIALOG ("Can't open file.", main_window);
       return (-1);
     }
 
-  read (catalog, &l, sizeof (gint));
+/* Test if the length is big enough */
+  l = lseek (catalog, 0, SEEK_END);
+  if (l < 8)
+    {
+      close (catalog);
+      ERROR_DIALOG ("File is not a GTKtalog file (v3 file format).",
+		    main_window);
+      return (-1);
+
+
+    }
+
+/* Test if this is an older version of gtktalog
+ * Older versions of gtktalog begin with "gtktalog"
+ */
+  l = lseek (catalog, 0, SEEK_SET);
+  read (catalog, fileformat, sizeof (gchar) * 8);
+  fileformat[8] = 0;
+  if (strcmp (fileformat, "gtktalog") == 0)
+    {
+      close (catalog);
+      ERROR_DIALOG
+	("File is seems to have been generated with a version older "
+	 "than 0.1.0 of GTKtalog. Formats are incompatibles. "
+	 "Send a mail to the authors to know what to do.", main_window);
+      return (-1);
+    }
+
+
+/* Test if this is a catalog in v3 format. */
+  l = lseek (catalog, 0, SEEK_SET);
+  read (catalog, &le, sizeof (gint));
+  l = GINT_FROM_LE (le);
+
   if ((l > 20) || (l < 5))
     {
       close (catalog);
-
-      /* Just a test to detect an version 1 or 2 of the file format */
-      if (strncmp ((gchar *) l, "gtktalog", sizeof (gint)) == 0)
-	{
-	  ERROR_DIALOG
-	    ("File is seems to have been generated with a version older "
-	     "than 0.1.0 of GTKtalog. Formats are incompatibles. "
-	     "Send a mail to the authors to know what to do.", main_window);
-	}
-      else
-	{
-	  ERROR_DIALOG ("File is not a GTKtalog file.", main_window);
-	}
+      ERROR_DIALOG ("File is not a GTKtalog file.", main_window);
       return (-1);
     }
   read (catalog, &fileformat, sizeof (gchar) * l);
@@ -226,6 +268,10 @@ load_cat_from_file (char *filename, FOLDER * racine)
 		    main_window);
       return (-1);
     }
+
+/* This is a gtktalog format. Test if it is compressed or not,
+ * and read the file.
+ */
   if (strcmp (fileformat, "gtktalog 3"))
     {
       gzcatalog = gzdopen (catalog, "rb");
